.. image:: https://img.shields.io/github/v/release/nuvolos-cloud/resolos
    :target: https://github.com/nuvolos-cloud/resolos

.. image:: https://readthedocs.org/projects/resolos/badge
    :target: https://resolos.readthedocs.io/en/latest/

Introduction
=======================================================

Resolos is a toolkit written in Python for maintaining reproducible environments for scientific computations.
It's main goal is to enable researchers to easily replicate environments through space (running code on HPC environment)
and time (environment preservation for long term archival).

Check out the project's homepage on `GitHub <https://github.com/nuvolos-cloud/resolos>`_.

Documentation available at `resolos.readthedocs.io <https://resolos.readthedocs.io/en/latest/>`_.
